@@ -30,7 +30,24 @@ CONFIG_MAP = {
             "--factor": "AWS_OKTA_FACTOR",
             "--silent": "AWS_OKTA_SILENT",
             "--no-okta-cache": "AWS_OKTA_NO_OKTA_CACHE",
-            "--no-aws-cache": "AWS_OKTA_NO_AWS_CACHE"
+            "--no-aws-cache": "AWS_OKTA_NO_AWS_CACHE",
+            "--account-alias": "AWS_OKTA_ACCOUNT_ALIAS"
+        }
+
+EXTEND_CONFIG_MAP = {
+            "AWS_OKTA_ENVIRONMENT": "environment",
+            "AWS_OKTA_USER": "user",
+            "AWS_OKTA_PASS": "pass",
+            "AWS_OKTA_ORGANIZATION": "organization",
+            "AWS_OKTA_APPLICATION": "application",
+            "AWS_OKTA_ROLE": "role",
+            "AWS_OKTA_DURATION": "duration",
+            "AWS_OKTA_KEY": "key",
+            "AWS_OKTA_FACTOR": "factor",
+            "AWS_OKTA_SILENT": "silent",
+            "AWS_OKTA_NO_OKTA_CACHE": "no-okta-cache",
+            "AWS_OKTA_NO_AWS_CACHE": "no-aws-cache",
+            "AWS_OKTA_ACCOUNT_ALIAS": "account-alias"
         }
 
 
@@ -82,7 +99,7 @@ class Authenticate(Base):
         configuration = {}
 
         for param, var in CONFIG_MAP.items():
-            if options[param]:
+            if options.get(param, None):
                 configuration[var] = options[param]
 
             if var not in configuration.keys():
@@ -91,4 +108,5 @@ class Authenticate(Base):
                 else:
                     configuration[var] = None
 
-        return configuration
+        return self.extend_configuration(configuration, 'authenticate',
+                                         EXTEND_CONFIG_MAP)
